Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3358)

Unified Diff: chrome/browser/views/tabs/tab_strip.h

Issue 1700016: Two changes to extension app icons:... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 10 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/views/tabs/tab_renderer.cc ('k') | chrome/browser/views/tabs/tab_strip.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/views/tabs/tab_strip.h
===================================================================
--- chrome/browser/views/tabs/tab_strip.h (revision 45537)
+++ chrome/browser/views/tabs/tab_strip.h (working copy)
@@ -5,6 +5,8 @@
#ifndef CHROME_BROWSER_VIEWS_TABS_TAB_STRIP_H_
#define CHROME_BROWSER_VIEWS_TABS_TAB_STRIP_H_
+#include <vector>
+
#include "app/animation_container.h"
#include "base/message_loop.h"
#include "base/ref_counted.h"
@@ -176,6 +178,10 @@
// Horizontal gap between mini and non-mini-tabs.
static const int mini_to_non_mini_gap_;
+ // Extra horizontal gap (on top of mini_to_non_mini_gap_) when one of the
+ // mini tabs is a nano tab.
+ static const int extra_gap_for_nano_;
+
private:
class RemoveTabDelegate;
@@ -270,6 +276,9 @@
// Returns the number of mini-tabs.
int GetMiniTabCount() const;
+ // Returns the number of nano-tabs.
+ int GetNanoTabCount() const;
+
// -- Tab Resize Layout -----------------------------------------------------
// Returns the exact (unrounded) current width of each tab.
@@ -280,10 +289,11 @@
// desired strip width and number of tabs. If
// |width_of_tabs_for_mouse_close_| is nonnegative we use that value in
// calculating the desired strip width; otherwise we use the current width.
// |mini_tab_count| gives the number of mini-tabs, and |tab_count| the
// number of mini and non-mini-tabs.
void GetDesiredTabWidths(int tab_count,
int mini_tab_count,
+ int nano_tab_count,
double* unselected_width,
double* selected_width) const;
« no previous file with comments | « chrome/browser/views/tabs/tab_renderer.cc ('k') | chrome/browser/views/tabs/tab_strip.cc » ('j') | no next file with comments »
@@ -280,10 +289,11 @@
// |width_of_tabs_for_mouse_close_| is nonnegative we use that value in
// calculating the desired strip width; otherwise we use the current width.
- // |mini_tab_count| gives the number of mini-tabs, and |tab_count| the
- // number of mini and non-mini-tabs.
+ // |mini_tab_count| gives the number of mini-tabs, |nano_tab_count| the
+ // number of mini-tabs and |tab_count| the number of mini and non-mini-tabs.
void GetDesiredTabWidths(int tab_count,
int mini_tab_count,

Powered by Google App Engine
This is Rietveld 408576698